@@ -1,24 +1,28 @@
+POINT = SymbolInfo("point")
+DIGITS = int(SymbolInfo("digits"))
+
 ood = GetOpenedOrderUIDs()
 if len(ood) == 0:
     pod = GetPendingOrderUIDs()
+    assertIsNotNone(pod)
     if len(pod) == 0:
         #
-        point = SymbolInfo("point")
         volume = 0.01
 
         # Buy all params
-        stop_loss = Ask() + 15 * point
-        take_profit = Bid() - 30 * point
+        stop_loss = round(Ask() + 15 * POINT, DIGITS)
+        take_profit = round(Bid() - 30 * POINT, DIGITS)
+        comment = "test selllimit"
         magic_number = 4301250
         # failed
-        price = Close()
+        price = Bid()
         errid, result = Sell(volume=0.01, type=OrderType.LIMIT, price=price, stop_loss=stop_loss,
                             take_profit=take_profit, magic_number=magic_number,
                             symbol=Symbol(), slippage=3, arrow_color="white")
         assertEqual(errid, EID_EAT_INVALID_LIMIT_ORDER_OPEN_PRICE)
 
         # failed
-        price = Close() + 10 * point
+        price = round(Bid() - 10 * POINT, DIGITS)
         errid, result = Sell(volume=0.01, type=OrderType.LIMIT, price=price, stop_loss=stop_loss,
                             take_profit=take_profit, magic_number=magic_number,
                             symbol=Symbol(), slippage=3, arrow_color="white")
@@ -33,16 +37,17 @@ if len(ood) == 0:
         assertIsNotNone(result)
         errid = exec_command()
         assertEqual(errid, 0)
-
         oo = GetPendingOrderUIDs()
         assertTrue(result['order_uid'] in oo)
+        order = GetOrder(result['order_uid'])
+        assertEqual(order.status, OrderStatus.PENDING)
 
         # modify
-        stop_loss = stop_loss + 15 * point
-        take_profit = take_profit - 30 * point
-        errid, result = ModifyOrder(result['order_uid'], price=Close()+1*point, stop_loss=stop_loss, take_profit=take_profit)
+        stop_loss = round(stop_loss + 15 * POINT, DIGITS)
+        take_profit = round(take_profit - 30 * POINT, DIGITS)
+        errid, result = ModifyOrder(result['order_uid'], price=Bid()-1*POINT, stop_loss=stop_loss, take_profit=take_profit)
         assertEqual(errid, EID_EAT_INVALID_LIMIT_ORDER_OPEN_PRICE)
-        errid, result = ModifyOrder(result['order_uid'], price=Close()-1*point, stop_loss=stop_loss, take_profit=take_profit)
+        errid, result = ModifyOrder(result['order_uid'], price=Bid()+1*POINT, stop_loss=stop_loss, take_profit=take_profit)
         assertEqual(errid, 0)
         assertIsNotNone(result['order_uid'])
         errid = exec_command()
@@ -57,13 +62,16 @@ if len(ood) == 0:
         assertEqual(order.take_profit, take_profit)
         assertIsNone(order.close_time)
         assertIsNone(order.close_price)
+        assertEqual(order.status, OrderStatus.PENDING)
 
         #close
-        errid, ct = CloseOrder(result['order_uid'], volume=volume, price=Bid())
+        errid, ct = CloseOrder(result['order_uid'], volume=volume, price=Ask())
         assertEqual(errid, 0)
         assertEqual(ct['order_uid'], result['order_uid'])
         errid = exec_command()
         assertEqual(errid, 0)
+        order = GetOrder(result['order_uid'])
+        assertEqual(order.status, OrderStatus.CANCELLED)
 
         # The order was closed ?
         oo = GetPendingOrderUIDs()
@@ -78,6 +86,8 @@ if len(ood) == 0:
         assertIsNotNone(result['order_uid'])
         errid = exec_command()
         assertEqual(errid, 0)
+        order = GetOrder(result['order_uid'])
+        assertEqual(order.status, OrderStatus.PENDING)
 
 else:
     pass
